sequencetools.partition_sequence_cyclically_by_weights_at_most_without_overhang
===============================================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_cyclically_by_weights_at_most_without_overhang
